#! /usr/lib/veetest/veetest -r
(revision "B.00.00")
(date "Mon 09/Nov/1992")
(component 0 "ROOTCONTEXT"
 (name "The Mole Game")
 (interface
 )
 (implementation
  (locked no)
  (trigMode deg)
  (nextID 28)
  (component 0 "CONTEXT"
   (name "I\'m a mole")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Delay")
     (requires
      (datatype Real)
      (shape "Scalar")
     )
     (optional yes)
    )
    (output 1
     (type data)
     (name "X")
     (lock constraints)
     (optional yes)
    )
    (output 2
     (type exception)
     (name "Error")
     (lock name constraints)
     (optional yes)
    )
   )
   (implementation
    (locked no)
    (trigMode deg)
    (nextID 4)
    (component 0 "DELAY"
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "Delay")
       (tag "Delay")
       (requires
        (datatype Real)
        (shape "Scalar")
       )
       (lock constraints)
       (optional yes)
       (buffer YES)
      )
      (output 1
       (type data)
       (name "Done")
       (tag "Done")
       (lock constraints)
      )
     )
     (implementation
      (component delay 1.5)
     )
     (views
      (icon
      )
      (detail
       (origin 655 233)
       (extent 130 34)
      )
      (active detail)
     )
    )
    (component 1 "EXITCONTEXT"
     (interface
      (sequence in)
     )
     (implementation
     )
     (views
      (icon
       (origin 668 308)
       (extent 145 25)
      )
      (detail
      )
      (terminals on)
      (active icon)
     )
    )
    (component 2 "CONFIRM"
     (name "Hit Me!")
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (name "Go")
       (lock name constraints)
      )
     )
     (implementation
     )
     (views
      (icon
       (origin 528 242)
       (extent 85 37)
      )
      (detail
       (origin 353 170)
       (extent 104 40)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 3 "ESCAPE"
     (interface
      (sequence in)
     )
     (implementation
      (component code 0)
      (component message "")
     )
     (views
      (icon
      )
      (detail
       (origin 500 339)
       (extent 140 63)
      )
      (active detail)
     )
    )
    (configuration
     (connect I1:1 D0:1)
     (connect D0:0 D1:0)
     (connect D2:1 D3:0)
     (connect D0:1 O1:1)
    )
    (ShowOnExecPanel
     (origin 95 360)
     (extent 97 73)
     (panel
      (origin 544 158)
      (extent 93 45)
      (widget 2 icon
       (title off)
       (origin 548 162)
       (extent 85 37)
      )
     )
    )
   )
   (views
    (icon
     (origin 545 333)
     (extent 110 25)
    )
    (detail
     (origin 466 184)
     (extent 369 233)
     (configuration
      (connect I1:1 D0:1
       (Point 468 310)
       (Point 480 310)
       (Point 480 220)
       (Point 630 220)
       (Point 630 250)
       (Point 652 250)
      )
      (connect D0:0 D1:0
       (Point 720 269)
       (Point 720 290)
       (Point 740 290)
       (Point 740 305)
      )
      (connect D2:1 D3:0
       (Point 615 260)
       (Point 630 260)
       (Point 630 290)
       (Point 570 290)
       (Point 570 308)
      )
      (connect D0:1 O1:1
       (Point 787 250)
       (Point 832 250)
      )
     )
     (stackingOrder 0 1 2 3)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 1 "CONTEXT"
   (name "I\'m a mole")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Delay")
     (requires
      (datatype Real)
      (shape "Scalar")
     )
     (optional yes)
    )
    (output 1
     (type data)
     (name "X")
     (lock constraints)
     (optional yes)
    )
    (output 2
     (type exception)
     (name "Error")
     (lock name constraints)
     (optional yes)
    )
   )
   (implementation
    (locked no)
    (trigMode deg)
    (nextID 4)
    (component 0 "DELAY"
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "Delay")
       (tag "Delay")
       (requires
        (datatype Real)
        (shape "Scalar")
       )
       (lock constraints)
       (optional yes)
       (buffer YES)
      )
      (output 1
       (type data)
       (name "Done")
       (tag "Done")
       (lock constraints)
      )
     )
     (implementation
      (component delay 1.5)
     )
     (views
      (icon
      )
      (detail
       (origin 655 233)
       (extent 130 34)
      )
      (active detail)
     )
    )
    (component 1 "EXITCONTEXT"
     (interface
      (sequence in)
     )
     (implementation
     )
     (views
      (icon
       (origin 668 308)
       (extent 145 25)
      )
      (detail
      )
      (terminals on)
      (active icon)
     )
    )
    (component 2 "CONFIRM"
     (name "Hit Me!")
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (name "Go")
       (lock name constraints)
      )
     )
     (implementation
     )
     (views
      (icon
       (origin 528 242)
       (extent 85 37)
      )
      (detail
       (origin 353 170)
       (extent 104 40)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 3 "ESCAPE"
     (interface
      (sequence in)
     )
     (implementation
      (component code 0)
      (component message "")
     )
     (views
      (icon
      )
      (detail
       (origin 500 339)
       (extent 140 63)
      )
      (active detail)
     )
    )
    (configuration
     (connect I1:1 D0:1)
     (connect D0:0 D1:0)
     (connect D2:1 D3:0)
     (connect D0:1 O1:1)
    )
    (ShowOnExecPanel
     (origin 412 301)
     (extent 97 73)
     (panel
      (origin 544 158)
      (extent 93 45)
      (widget 2 icon
       (title off)
       (origin 548 162)
       (extent 85 37)
      )
     )
    )
   )
   (views
    (icon
     (origin 545 373)
     (extent 110 25)
    )
    (detail
     (origin 466 184)
     (extent 369 233)
     (configuration
      (connect I1:1 D0:1
       (Point 468 310)
       (Point 480 310)
       (Point 480 220)
       (Point 630 220)
       (Point 630 250)
       (Point 652 250)
      )
      (connect D0:0 D1:0
       (Point 720 269)
       (Point 720 290)
       (Point 740 290)
       (Point 740 305)
      )
      (connect D2:1 D3:0
       (Point 615 260)
       (Point 630 260)
       (Point 630 290)
       (Point 570 290)
       (Point 570 308)
      )
      (connect D0:1 O1:1
       (Point 787 250)
       (Point 832 250)
      )
     )
     (stackingOrder 0 1 2 3)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 2 "CONTEXT"
   (name "I\'m a mole")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Delay")
     (requires
      (datatype Real)
      (shape "Scalar")
     )
     (optional yes)
    )
    (output 1
     (type data)
     (name "X")
     (lock constraints)
     (optional yes)
    )
    (output 2
     (type exception)
     (name "Error")
     (lock name constraints)
     (optional yes)
    )
   )
   (implementation
    (locked no)
    (trigMode deg)
    (nextID 4)
    (component 0 "DELAY"
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "Delay")
       (tag "Delay")
       (requires
        (datatype Real)
        (shape "Scalar")
       )
       (lock constraints)
       (optional yes)
       (buffer YES)
      )
      (output 1
       (type data)
       (name "Done")
       (tag "Done")
       (lock constraints)
      )
     )
     (implementation
      (component delay 1.5)
     )
     (views
      (icon
      )
      (detail
       (origin 655 233)
       (extent 130 34)
      )
      (active detail)
     )
    )
    (component 1 "EXITCONTEXT"
     (interface
      (sequence in)
     )
     (implementation
     )
     (views
      (icon
       (origin 668 308)
       (extent 145 25)
      )
      (detail
      )
      (terminals on)
      (active icon)
     )
    )
    (component 2 "CONFIRM"
     (name "Hit Me!")
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (name "Go")
       (lock name constraints)
      )
     )
     (implementation
     )
     (views
      (icon
       (origin 528 242)
       (extent 85 37)
      )
      (detail
       (origin 353 170)
       (extent 104 40)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 3 "ESCAPE"
     (interface
      (sequence in)
     )
     (implementation
      (component code 0)
      (component message "")
     )
     (views
      (icon
      )
      (detail
       (origin 500 339)
       (extent 140 63)
      )
      (active detail)
     )
    )
    (configuration
     (connect I1:1 D0:1)
     (connect D0:0 D1:0)
     (connect D2:1 D3:0)
     (connect D0:1 O1:1)
    )
    (ShowOnExecPanel
     (origin 371 461)
     (extent 97 73)
     (panel
      (origin 544 158)
      (extent 93 45)
      (widget 2 icon
       (title off)
       (origin 548 162)
       (extent 85 37)
      )
     )
    )
   )
   (views
    (icon
     (origin 545 613)
     (extent 110 25)
    )
    (detail
     (origin 466 184)
     (extent 369 233)
     (configuration
      (connect I1:1 D0:1
       (Point 468 310)
       (Point 480 310)
       (Point 480 220)
       (Point 630 220)
       (Point 630 250)
       (Point 652 250)
      )
      (connect D0:0 D1:0
       (Point 720 269)
       (Point 720 290)
       (Point 740 290)
       (Point 740 305)
      )
      (connect D2:1 D3:0
       (Point 615 260)
       (Point 630 260)
       (Point 630 290)
       (Point 570 290)
       (Point 570 308)
      )
      (connect D0:1 O1:1
       (Point 787 250)
       (Point 832 250)
      )
     )
     (stackingOrder 0 1 2 3)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 3 "CONTEXT"
   (name "I\'m a mole")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Delay")
     (requires
      (datatype Real)
      (shape "Scalar")
     )
     (optional yes)
    )
    (output 1
     (type data)
     (name "X")
     (lock constraints)
     (optional yes)
    )
    (output 2
     (type exception)
     (name "Error")
     (lock name constraints)
     (optional yes)
    )
   )
   (implementation
    (locked no)
    (trigMode deg)
    (nextID 4)
    (component 0 "DELAY"
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "Delay")
       (tag "Delay")
       (requires
        (datatype Real)
        (shape "Scalar")
       )
       (lock constraints)
       (optional yes)
       (buffer YES)
      )
      (output 1
       (type data)
       (name "Done")
       (tag "Done")
       (lock constraints)
      )
     )
     (implementation
      (component delay 1.5)
     )
     (views
      (icon
      )
      (detail
       (origin 655 233)
       (extent 130 34)
      )
      (active detail)
     )
    )
    (component 1 "EXITCONTEXT"
     (interface
      (sequence in)
     )
     (implementation
     )
     (views
      (icon
       (origin 668 308)
       (extent 145 25)
      )
      (detail
      )
      (terminals on)
      (active icon)
     )
    )
    (component 2 "CONFIRM"
     (name "Hit Me!")
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (name "Go")
       (lock name constraints)
      )
     )
     (implementation
     )
     (views
      (icon
       (origin 528 242)
       (extent 85 37)
      )
      (detail
       (origin 353 170)
       (extent 104 40)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 3 "ESCAPE"
     (interface
      (sequence in)
     )
     (implementation
      (component code 0)
      (component message "")
     )
     (views
      (icon
      )
      (detail
       (origin 500 339)
       (extent 140 63)
      )
      (active detail)
     )
    )
    (configuration
     (connect I1:1 D0:1)
     (connect D0:0 D1:0)
     (connect D2:1 D3:0)
     (connect D0:1 O1:1)
    )
    (ShowOnExecPanel
     (origin 277 242)
     (extent 97 73)
     (panel
      (origin 544 158)
      (extent 93 45)
      (widget 2 icon
       (title off)
       (origin 548 162)
       (extent 85 37)
      )
     )
    )
   )
   (views
    (icon
     (origin 545 573)
     (extent 110 25)
    )
    (detail
     (origin 466 184)
     (extent 369 233)
     (configuration
      (connect I1:1 D0:1
       (Point 468 310)
       (Point 480 310)
       (Point 480 220)
       (Point 630 220)
       (Point 630 250)
       (Point 652 250)
      )
      (connect D0:0 D1:0
       (Point 720 269)
       (Point 720 290)
       (Point 740 290)
       (Point 740 305)
      )
      (connect D2:1 D3:0
       (Point 615 260)
       (Point 630 260)
       (Point 630 290)
       (Point 570 290)
       (Point 570 308)
      )
      (connect D0:1 O1:1
       (Point 787 250)
       (Point 832 250)
      )
     )
     (stackingOrder 0 1 2 3)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 4 "CONTEXT"
   (name "I\'m a mole")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Delay")
     (requires
      (datatype Real)
      (shape "Scalar")
     )
     (optional yes)
    )
    (output 1
     (type data)
     (name "X")
     (lock constraints)
     (optional yes)
    )
    (output 2
     (type exception)
     (name "Error")
     (lock name constraints)
     (optional yes)
    )
   )
   (implementation
    (locked no)
    (trigMode deg)
    (nextID 4)
    (component 0 "DELAY"
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "Delay")
       (tag "Delay")
       (requires
        (datatype Real)
        (shape "Scalar")
       )
       (lock constraints)
       (optional yes)
       (buffer YES)
      )
      (output 1
       (type data)
       (name "Done")
       (tag "Done")
       (lock constraints)
      )
     )
     (implementation
      (component delay 1.5)
     )
     (views
      (icon
      )
      (detail
       (origin 655 233)
       (extent 130 34)
      )
      (active detail)
     )
    )
    (component 1 "EXITCONTEXT"
     (interface
      (sequence in)
     )
     (implementation
     )
     (views
      (icon
       (origin 668 308)
       (extent 145 25)
      )
      (detail
      )
      (terminals on)
      (active icon)
     )
    )
    (component 2 "CONFIRM"
     (name "Hit Me!")
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (name "Go")
       (lock name constraints)
      )
     )
     (implementation
     )
     (views
      (icon
       (origin 528 242)
       (extent 85 37)
      )
      (detail
       (origin 353 170)
       (extent 104 40)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 3 "ESCAPE"
     (interface
      (sequence in)
     )
     (implementation
      (component code 0)
      (component message "")
     )
     (views
      (icon
      )
      (detail
       (origin 500 339)
       (extent 140 63)
      )
      (active detail)
     )
    )
    (configuration
     (connect I1:1 D0:1)
     (connect D0:0 D1:0)
     (connect D2:1 D3:0)
     (connect D0:1 O1:1)
    )
    (ShowOnExecPanel
     (origin 530 405)
     (extent 97 73)
     (panel
      (origin 544 158)
      (extent 93 45)
      (widget 2 icon
       (title off)
       (origin 548 162)
       (extent 85 37)
      )
     )
    )
   )
   (views
    (icon
     (origin 545 533)
     (extent 110 25)
    )
    (detail
     (origin 466 184)
     (extent 369 233)
     (configuration
      (connect I1:1 D0:1
       (Point 468 310)
       (Point 480 310)
       (Point 480 220)
       (Point 630 220)
       (Point 630 250)
       (Point 652 250)
      )
      (connect D0:0 D1:0
       (Point 720 269)
       (Point 720 290)
       (Point 740 290)
       (Point 740 305)
      )
      (connect D2:1 D3:0
       (Point 615 260)
       (Point 630 260)
       (Point 630 290)
       (Point 570 290)
       (Point 570 308)
      )
      (connect D0:1 O1:1
       (Point 787 250)
       (Point 832 250)
      )
     )
     (stackingOrder 0 1 2 3)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 5 "CONTEXT"
   (name "I\'m a mole")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Delay")
     (requires
      (datatype Real)
      (shape "Scalar")
     )
     (optional yes)
    )
    (output 1
     (type data)
     (name "X")
     (lock constraints)
     (optional yes)
    )
    (output 2
     (type exception)
     (name "Error")
     (lock name constraints)
     (optional yes)
    )
   )
   (implementation
    (locked no)
    (trigMode deg)
    (nextID 4)
    (component 0 "DELAY"
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "Delay")
       (tag "Delay")
       (requires
        (datatype Real)
        (shape "Scalar")
       )
       (lock constraints)
       (optional yes)
       (buffer YES)
      )
      (output 1
       (type data)
       (name "Done")
       (tag "Done")
       (lock constraints)
      )
     )
     (implementation
      (component delay 1.5)
     )
     (views
      (icon
      )
      (detail
       (origin 655 233)
       (extent 130 34)
      )
      (active detail)
     )
    )
    (component 1 "EXITCONTEXT"
     (interface
      (sequence in)
     )
     (implementation
     )
     (views
      (icon
       (origin 668 308)
       (extent 145 25)
      )
      (detail
      )
      (terminals on)
      (active icon)
     )
    )
    (component 2 "CONFIRM"
     (name "Hit Me!")
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (name "Go")
       (lock name constraints)
      )
     )
     (implementation
     )
     (views
      (icon
       (origin 528 242)
       (extent 85 37)
      )
      (detail
       (origin 353 170)
       (extent 104 40)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 3 "ESCAPE"
     (interface
      (sequence in)
     )
     (implementation
      (component code 0)
      (component message "")
     )
     (views
      (icon
      )
      (detail
       (origin 500 339)
       (extent 140 63)
      )
      (active detail)
     )
    )
    (configuration
     (connect I1:1 D0:1)
     (connect D0:0 D1:0)
     (connect D2:1 D3:0)
     (connect D0:1 O1:1)
    )
    (ShowOnExecPanel
     (origin 692 262)
     (extent 97 73)
     (panel
      (origin 544 158)
      (extent 93 45)
      (widget 2 icon
       (title off)
       (origin 548 162)
       (extent 85 37)
      )
     )
    )
   )
   (views
    (icon
     (origin 545 413)
     (extent 110 25)
    )
    (detail
     (origin 466 184)
     (extent 369 233)
     (configuration
      (connect I1:1 D0:1
       (Point 468 310)
       (Point 480 310)
       (Point 480 220)
       (Point 630 220)
       (Point 630 250)
       (Point 652 250)
      )
      (connect D0:0 D1:0
       (Point 720 269)
       (Point 720 290)
       (Point 740 290)
       (Point 740 305)
      )
      (connect D2:1 D3:0
       (Point 615 260)
       (Point 630 260)
       (Point 630 290)
       (Point 570 290)
       (Point 570 308)
      )
      (connect D0:1 O1:1
       (Point 787 250)
       (Point 832 250)
      )
     )
     (stackingOrder 0 1 2 3)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 6 "CONTEXT"
   (name "I\'m a mole")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Delay")
     (requires
      (datatype Real)
      (shape "Scalar")
     )
     (optional yes)
    )
    (output 1
     (type data)
     (name "X")
     (lock constraints)
     (optional yes)
    )
    (output 2
     (type exception)
     (name "Error")
     (lock name constraints)
     (optional yes)
    )
   )
   (implementation
    (locked no)
    (trigMode deg)
    (nextID 4)
    (component 0 "DELAY"
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "Delay")
       (tag "Delay")
       (requires
        (datatype Real)
        (shape "Scalar")
       )
       (lock constraints)
       (optional yes)
       (buffer YES)
      )
      (output 1
       (type data)
       (name "Done")
       (tag "Done")
       (lock constraints)
      )
     )
     (implementation
      (component delay 1.5)
     )
     (views
      (icon
      )
      (detail
       (origin 655 233)
       (extent 130 34)
      )
      (active detail)
     )
    )
    (component 1 "EXITCONTEXT"
     (interface
      (sequence in)
     )
     (implementation
     )
     (views
      (icon
       (origin 668 308)
       (extent 145 25)
      )
      (detail
      )
      (terminals on)
      (active icon)
     )
    )
    (component 2 "CONFIRM"
     (name "Hit Me!")
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (name "Go")
       (lock name constraints)
      )
     )
     (implementation
     )
     (views
      (icon
       (origin 528 242)
       (extent 85 37)
      )
      (detail
       (origin 353 170)
       (extent 104 40)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 3 "ESCAPE"
     (interface
      (sequence in)
     )
     (implementation
      (component code 0)
      (component message "")
     )
     (views
      (icon
      )
      (detail
       (origin 500 339)
       (extent 140 63)
      )
      (active detail)
     )
    )
    (configuration
     (connect I1:1 D0:1)
     (connect D0:0 D1:0)
     (connect D2:1 D3:0)
     (connect D0:1 O1:1)
    )
    (ShowOnExecPanel
     (origin 585 436)
     (extent 97 73)
     (panel
      (origin 544 158)
      (extent 93 45)
      (widget 2 icon
       (title off)
       (origin 548 162)
       (extent 85 37)
      )
     )
    )
   )
   (views
    (icon
     (origin 545 453)
     (extent 110 25)
    )
    (detail
     (origin 466 184)
     (extent 369 233)
     (configuration
      (connect I1:1 D0:1
       (Point 468 310)
       (Point 480 310)
       (Point 480 220)
       (Point 630 220)
       (Point 630 250)
       (Point 652 250)
      )
      (connect D0:0 D1:0
       (Point 720 269)
       (Point 720 290)
       (Point 740 290)
       (Point 740 305)
      )
      (connect D2:1 D3:0
       (Point 615 260)
       (Point 630 260)
       (Point 630 290)
       (Point 570 290)
       (Point 570 308)
      )
      (connect D0:1 O1:1
       (Point 787 250)
       (Point 832 250)
      )
     )
     (stackingOrder 0 1 2 3)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 7 "CONTEXT"
   (name "I\'m a mole")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Delay")
     (requires
      (datatype Real)
      (shape "Scalar")
     )
     (optional yes)
    )
    (output 1
     (type data)
     (name "X")
     (lock constraints)
     (optional yes)
    )
    (output 2
     (type exception)
     (name "Error")
     (lock name constraints)
     (optional yes)
    )
   )
   (implementation
    (locked no)
    (trigMode deg)
    (nextID 4)
    (component 0 "DELAY"
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "Delay")
       (tag "Delay")
       (requires
        (datatype Real)
        (shape "Scalar")
       )
       (lock constraints)
       (optional yes)
       (buffer YES)
      )
      (output 1
       (type data)
       (name "Done")
       (tag "Done")
       (lock constraints)
      )
     )
     (implementation
      (component delay 1.5)
     )
     (views
      (icon
      )
      (detail
       (origin 655 233)
       (extent 130 34)
      )
      (active detail)
     )
    )
    (component 1 "EXITCONTEXT"
     (interface
      (sequence in)
     )
     (implementation
     )
     (views
      (icon
       (origin 668 308)
       (extent 145 25)
      )
      (detail
      )
      (terminals on)
      (active icon)
     )
    )
    (component 2 "CONFIRM"
     (name "Hit Me!")
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (name "Go")
       (lock name constraints)
      )
     )
     (implementation
     )
     (views
      (icon
       (origin 528 242)
       (extent 85 37)
      )
      (detail
       (origin 353 170)
       (extent 104 40)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 3 "ESCAPE"
     (interface
      (sequence in)
     )
     (implementation
      (component code 0)
      (component message "")
     )
     (views
      (icon
      )
      (detail
       (origin 500 339)
       (extent 140 63)
      )
      (active detail)
     )
    )
    (configuration
     (connect I1:1 D0:1)
     (connect D0:0 D1:0)
     (connect D2:1 D3:0)
     (connect D0:1 O1:1)
    )
    (ShowOnExecPanel
     (origin 758 415)
     (extent 97 73)
     (panel
      (origin 544 158)
      (extent 93 45)
      (widget 2 icon
       (title off)
       (origin 548 162)
       (extent 85 37)
      )
     )
    )
   )
   (views
    (icon
     (origin 545 493)
     (extent 110 25)
    )
    (detail
     (origin 466 184)
     (extent 369 233)
     (configuration
      (connect I1:1 D0:1
       (Point 468 310)
       (Point 480 310)
       (Point 480 220)
       (Point 630 220)
       (Point 630 250)
       (Point 652 250)
      )
      (connect D0:0 D1:0
       (Point 720 269)
       (Point 720 290)
       (Point 740 290)
       (Point 740 305)
      )
      (connect D2:1 D3:0
       (Point 615 260)
       (Point 630 260)
       (Point 630 290)
       (Point 570 290)
       (Point 570 308)
      )
      (connect D0:1 O1:1
       (Point 787 250)
       (Point 832 250)
      )
     )
     (stackingOrder 0 1 2 3)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 8 "CONTEXT"
   (name "I\'m a mole")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Delay")
     (requires
      (datatype Real)
      (shape "Scalar")
     )
     (optional yes)
    )
    (output 1
     (type data)
     (name "X")
     (lock constraints)
     (optional yes)
    )
    (output 2
     (type exception)
     (name "Error")
     (lock name constraints)
     (optional yes)
    )
   )
   (implementation
    (locked no)
    (trigMode deg)
    (nextID 4)
    (component 0 "DELAY"
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "Delay")
       (tag "Delay")
       (requires
        (datatype Real)
        (shape "Scalar")
       )
       (lock constraints)
       (optional yes)
       (buffer YES)
      )
      (output 1
       (type data)
       (name "Done")
       (tag "Done")
       (lock constraints)
      )
     )
     (implementation
      (component delay 1.5)
     )
     (views
      (icon
      )
      (detail
       (origin 605 163)
       (extent 130 34)
      )
      (active detail)
     )
    )
    (component 1 "EXITCONTEXT"
     (interface
      (sequence in)
     )
     (implementation
     )
     (views
      (icon
       (origin 618 238)
       (extent 145 25)
      )
      (detail
      )
      (terminals on)
      (active icon)
     )
    )
    (component 2 "CONFIRM"
     (name "Hit Me!")
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (name "Go")
       (lock name constraints)
      )
     )
     (implementation
     )
     (views
      (icon
       (origin 478 172)
       (extent 85 37)
      )
      (detail
       (origin 353 170)
       (extent 104 40)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 3 "ESCAPE"
     (interface
      (sequence in)
     )
     (implementation
      (component code 0)
      (component message "")
     )
     (views
      (icon
      )
      (detail
       (origin 450 269)
       (extent 140 63)
      )
      (active detail)
     )
    )
    (configuration
     (connect I1:1 D0:1)
     (connect D0:0 D1:0)
     (connect D2:1 D3:0)
     (connect D0:1 O1:1)
    )
    (ShowOnExecPanel
     (origin 62 244)
     (extent 97 73)
     (panel
      (origin 544 158)
      (extent 93 45)
      (widget 2 icon
       (title off)
       (origin 548 162)
       (extent 85 37)
      )
     )
    )
   )
   (views
    (icon
     (origin 545 293)
     (extent 110 25)
    )
    (detail
     (origin 416 114)
     (extent 369 233)
     (configuration
      (connect I1:1 D0:1
       (Point 418 240)
       (Point 430 240)
       (Point 430 150)
       (Point 580 150)
       (Point 580 180)
       (Point 602 180)
      )
      (connect D0:0 D1:0
       (Point 670 199)
       (Point 670 220)
       (Point 690 220)
       (Point 690 235)
      )
      (connect D2:1 D3:0
       (Point 565 190)
       (Point 580 190)
       (Point 580 220)
       (Point 520 220)
       (Point 520 238)
      )
      (connect D0:1 O1:1
       (Point 737 180)
       (Point 782 180)
      )
     )
     (stackingOrder 0 1 2 3)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 9 "CONFIRM"
   (name "Stop")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type trigger)
     (name "XEQ")
     (lock name constraints)
     (optional yes)
    )
    (output 1
     (type data)
     (name "Go")
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 21 357)
     (extent 58 37)
    )
    (detail
     (origin 80 300)
     (extent 50 40)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 10 "COUNTER"
   (name "Misses")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
    (output 1
     (type data)
     (name "Count")
     (tag "Count")
     (lock name constraints)
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (extent 78 0)
    )
    (detail
     (origin 855 248)
     (extent 150 34)
    )
    (active detail)
   )
  )
  (component 11 "TOGGLE"
   (name "show oops")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Toggle")
     (lock name constraints)
    )
   )
   (implementation
    (component value Int32
     (name "show oops")
     (values range 0 1)
     (datum 1)
    )
    (component autoTrigger off)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Int32
     (name "LongInt")
     (datum 0)
    )
   )
   (views
    (icon
     (origin 861 302)
     (extent 138 27)
     (format check box)
    )
    (detail
     (origin 778 480)
     (extent 65 40)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 12 "IFTHENELSE"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Then")
     (lock name constraints)
    )
    (output 2
     (type data)
     (name "Else")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr "a")
   )
   (views
    (icon
     (origin 891 363)
     (extent 78 25)
    )
    (detail
     (origin 738 645)
     (extent 55 70)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 13 "CONTEXT"
   (name "Oops...")
   (interface
    (sequence in)
    (sequence out)
   )
   (implementation
    (locked no)
    (trigMode deg)
    (nextID 3)
    (component 0 "LITERALCONSTANT"
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (name "Text")
       (lock name constraints)
      )
     )
     (implementation
      (component value Text
       (name "Text")
       (datum "You Missed!")
      )
      (component autoTrigger off)
      (component initializeAtPrerun off)
      (component initializeAtActivate off)
      (component initValue Text
       (name "CString")
       (datum "")
      )
     )
     (views
      (icon
      )
      (detail
       (origin 324 525)
       (extent 192 30)
      )
      (active detail)
     )
    )
    (component 1 "DELAY"
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (name "Done")
       (tag "Done")
       (lock constraints)
      )
     )
     (implementation
      (component delay 1)
     )
     (views
      (icon
      )
      (detail
       (origin 395 723)
       (extent 130 34)
      )
      (active detail)
     )
    )
    (component 2 "TEXTDISPLAY"
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "Data")
      )
     )
     (implementation
      (component clearAtPrerun 1)
      (component clearAtActivate 1)
     )
     (views
      (icon
      )
      (detail
       (origin 355 632)
       (extent 190 37)
      )
      (active detail)
     )
    )
    (configuration
     (connect D2:0 D1:0)
     (connect D0:1 D2:1)
    )
    (ShowOnExecPanel
     (origin 331 267)
     (extent 209 69)
     (panel
      (origin 578 350)
      (extent 205 41)
      (widget 2 detail
       (title off)
       (origin 586 355)
       (extent 190 29)
      )
     )
    )
   )
   (views
    (icon
     (origin 891 423)
     (extent 78 25)
    )
    (detail
     (origin 295 480)
     (extent 350 300)
     (configuration
      (connect D2:0 D1:0
       (Point 450 671)
       (Point 450 680)
       (Point 460 680)
       (Point 460 692)
      )
      (connect D0:1 D2:1
       (Point 518 540)
       (Point 540 540)
       (Point 540 580)
       (Point 330 580)
       (Point 330 650)
       (Point 352 650)
      )
     )
     (stackingOrder 0 1 2)
    )
    (active icon)
   )
  )
  (component 14 "JUNCTION"
   (name "JCT")
   (interface
    (input 1
     (type data)
     (name "A")
     (lock name constraints)
    )
    (input 2
     (type data)
     (name "B")
     (lock name constraints)
    )
    (input 3
     (type data)
     (name "C")
     (optional yes)
    )
    (input 4
     (type data)
     (name "D")
     (optional yes)
    )
    (input 5
     (type data)
     (name "E")
     (optional yes)
    )
    (input 6
     (type data)
     (name "F")
     (optional yes)
    )
    (input 7
     (type data)
     (name "G")
     (optional yes)
    )
    (input 8
     (type data)
     (name "H")
     (optional yes)
    )
    (input 9
     (type data)
     (name "I")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Data")
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 787 218)
     (extent 46 94)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 15 "JUNCTION"
   (name "JCT")
   (interface
    (input 1
     (type data)
     (name "A")
     (lock name constraints)
    )
    (input 2
     (type data)
     (name "B")
     (lock name constraints)
    )
    (input 3
     (type data)
     (name "C")
     (optional yes)
    )
    (input 4
     (type data)
     (name "D")
     (optional yes)
    )
    (input 5
     (type data)
     (name "E")
     (optional yes)
    )
    (input 6
     (type data)
     (name "F")
     (optional yes)
    )
    (input 7
     (type data)
     (name "G")
     (optional yes)
    )
    (input 8
     (type data)
     (name "H")
     (optional yes)
    )
    (input 9
     (type data)
     (name "I")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Data")
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 797 568)
     (extent 46 94)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 16 "COUNTER"
   (name "Hits")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
    (output 1
     (type data)
     (name "Count")
     (tag "Count")
     (lock name constraints)
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (extent 46 0)
    )
    (detail
     (origin 865 598)
     (extent 150 34)
    )
    (active detail)
   )
  )
  (component 17 "START"
   (interface
    (sequence out)
   )
   (implementation
   )
   (views
    (icon
     (origin 77 82)
     (extent 67 37)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 18 "FORCOUNT"
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Count")
     (lock name constraints)
    )
   )
   (implementation
    (component count 20)
   )
   (views
    (icon
     (origin 65 263)
     (extent 110 64)
     (iconImage "loop.icon")
    )
    (detail
     (origin 45 273)
     (extent 170 34)
    )
    (active icon)
   )
  )
  (component 19 "NOTE"
   (name "Warranty Disclaimer")
   (interface
   )
   (implementation
    (component text 5 5
     This example is provided as an
     illustration "as is", and Hewlett-
     Packard Company makes no warranty
     of any kind with regard to this
     example.
    )
   )
   (views
    (icon
     (origin 190 153)
     (extent 181 25)
    )
    (detail
     (origin 285 111)
     (extent 330 99)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 20 "ENUMCONSTANT"
   (name "Skill Level")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Enum")
     (lock name constraints)
    )
   )
   (implementation
    (component value Enum
     (name "Skill Level")
     (values
      ( "Beginner" 0)
      ( "Advanced" 1)
      ( "Expert" 2)
     )
     (datum "Beginner")
    )
    (component autoTrigger off)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Enum
     (name "Enum")
     (shared yes)
     (datum "Beginner")
    )
   )
   (views
    (icon
     (extent 110 0)
    )
    (detail
     (origin 19 535)
     (extent 182 81)
     (format buttons)
    )
    (active detail)
   )
  )
  (component 21 "EXITPROCESS"
   (interface
    (sequence in)
   )
   (implementation
    (comp code 0)
   )
   (views
    (icon
     (origin 11 423)
     (extent 78 64)
     (iconImage "stop.icon")
    )
    (detail
     (origin 70 503)
     (extent 120 34)
    )
    (active icon)
   )
  )
  (component 22 "FORMULA"
   (name "delay time")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr 1 "1.5-.5*ordinal(a)")
   )
   (views
    (icon
     (origin 135 373)
     (extent 110 64)
     (iconImage "formula.icon")
    )
    (detail
     (origin 57 361)
     (extent 196 78)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 23 "DEMULTIPLEXER"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
     (lock name constraints)
    )
    (input 2
     (type data)
     (name "Addr")
     (requires
      (datatype Int32)
      (shape "Scalar")
     )
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Addr 0")
     (lock name constraints)
     (optional yes)
    )
    (output 2
     (type data)
     (name "Addr 1")
     (lock name constraints)
     (optional yes)
    )
    (output 3
     (type data)
     (name "Addr 2")
     (lock constraints)
     (optional yes)
    )
    (output 4
     (type data)
     (name "Addr 3")
     (lock constraints)
     (optional yes)
    )
    (output 5
     (type data)
     (name "Addr 4")
     (lock constraints)
     (optional yes)
    )
    (output 6
     (type data)
     (name "Addr 5")
     (lock constraints)
     (optional yes)
    )
    (output 7
     (type data)
     (name "Addr 6")
     (lock constraints)
     (optional yes)
    )
    (output 8
     (type data)
     (name "Addr 7")
     (lock constraints)
     (optional yes)
    )
    (output 9
     (type data)
     (name "Addr 8")
     (lock constraints)
     (optional yes)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 297 448)
     (extent 127 25)
    )
    (detail
     (origin 330 333)
     (extent 70 304)
    )
    (terminals on)
    (active detail)
   )
  )
  (component 24 "RANDOMNUMBER"
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Rand Val")
     (lock name constraints)
    )
   )
   (implementation
    (component lowerLimit -0.4999)
    (component upperLimit 8.4999)
   )
   (views
    (icon
     (origin 47 633)
     (extent 127 25)
    )
    (detail
     (origin 31 610)
     (extent 159 60)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 25 "CONTEXT"
   (name "Press For")
   (interface
    (sequence in)
    (sequence out)
   )
   (implementation
    (locked no)
    (trigMode deg)
    (nextID 3)
    (component 0 "IFTHENELSE"
     (name "!= 0")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "A")
       (optional yes)
      )
      (output 1
       (type data)
       (name "Then")
       (lock name constraints)
      )
      (output 2
       (type data)
       (name "Else")
       (lock name constraints)
      )
     )
     (implementation
      (component isLocked no)
      (component expr "a!=0")
     )
     (views
      (icon
       (origin 415 350)
       (extent 46 25)
      )
      (detail
       (origin 209 308)
       (extent 73 64)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 1 "TOGGLE"
     (name "Info About")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type control)
       (name "Reset")
       (lock name constraints)
       (optional yes)
      )
      (output 1
       (type data)
       (lock name constraints)
      )
     )
     (implementation
      (component value Int32
       (name "Info About")
       (values range 0 1)
       (datum 0)
      )
      (component autoTrigger on)
      (component initializeAtPrerun off)
      (component initializeAtActivate off)
      (component initValue Int32
       (name "LongInt")
       (datum 0)
      )
     )
     (views
      (icon
       (origin 251 343)
       (extent 114 39)
       (format button)
      )
      (detail
       (origin 320 203)
       (extent 42 54)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 2 "CONTEXT"
     (name "Info About This Example")
     (interface
      (sequence in)
      (sequence out)
     )
     (implementation
      (locked no)
      (trigMode deg)
      (nextID 2)
      (component 0 "CONFIRM"
       (name "DONE")
       (description 7 8
        This tiny "thread" begins running when the 
        enclosing UserObject is executed.  When the user
        acknowledges the OK/DONE button, there is nothing
        left to execute, so the thread ends.  Since there
        are not other threads running, the User Object
        is completed and will exit, removing the Show on
        Execute pop-up display.
       )
       (interface
        (sequence in)
        (sequence out)
        (output 1
         (type data)
         (name "Go")
         (lock name constraints)
        )
       )
       (implementation
       )
       (views
        (icon
         (origin 421 482)
         (extent 58 37)
        )
        (detail
         (origin 156 253)
         (extent 79 34)
        )
        (terminals on)
        (active icon)
       )
      )
      (component 1 "NOTE"
       (name "NotePad")
       (description 2 8
        This notepad is displayed as a Show on Execute
        panel to present the information to the reader.
       )
       (interface
       )
       (implementation
        (component text 20 9
         PURPOSE:      Illustrates several useful techniques with User Objects, Show Panel On
                       Execute, and building a User panel STOP button.  A secondary purpose is
                       to exercise your motor skills using the mouse.
         
         USER INPUT REQUIRED: Set the desired Skill Level and press Start button or RUN to begin.
         
         EXPLANATION:  Based on the selected Skill Level, a delay time is calculated.  For each
                       iteration of the For Count, a random number between -0.5 and 8.499 is
                       chosen and used as the Address input of a DeMultiplexer.  Because the
                       DeMultiplexer needs an Int32 for an address, the address is rounded to
                       an integer between 0 and 8, and used to select the output terminal to
                       send the Data input container to.  Thus, the delay value is randomly
                       sent to one of the 9 "I'm a mole" objects.
         
                       Each "mole" is a User Object with a Confirm/Ok button (relabeled "Hit Me")
                       added to the User Object's panel.  The Show On Execute flag is set for 
                       each mole, causing it to pop up on the workspace at the location where it
                       was last "positioned" before the program was saved.  Thus, each mole only
                       pops up in one location; the random order that the moles are invoked is
                       the source of the apparently random locations.
        )
       )
       (views
        (icon
         (origin 410 415)
         (extent 78 25)
        )
        (detail
         (origin 25 209)
         (extent 848 437)
         (editing disabled)
        )
        (active icon)
       )
      )
      (configuration
      )
      (ShowOnExecPanel
       (origin 48 78)
       (extent 849 561)
       (panel
        (origin 88 164)
        (extent 845 533)
        (widget 0 icon
         (title off)
         (origin 487 649)
         (extent 58 37)
        )
        (widget 1 detail
         (title off)
         (origin 95 175)
         (extent 832 463)
         (editing disabled)
        )
       )
      )
     )
     (views
      (icon
       (origin 402 418)
       (extent 217 25)
      )
      (detail
       (origin 17 160)
       (extent 866 520)
       (configuration
       )
       (stackingOrder 0 1)
      )
      (active icon)
     )
    )
    (configuration
     (connect D1:1 D0:1)
     (connect D2:0 D1:1)
     (connect D0:1 D2:0)
    )
   )
   (views
    (icon
     (origin 415 408)
     (extent 110 25)
    )
    (panel
     (origin 695 108)
     (extent 291 65)
     (widget 1 icon
      (title off)
      (origin 782 119)
      (extent 114 39)
      (format button)
     )
    )
    (detail
     (origin 54 115)
     (extent 912 591)
     (configuration
      (connect D1:1 D0:1
       (Point 367 362)
       (Point 412 362)
      )
      (connect D2:0 D1:1
       (Point 510 445)
       (Point 510 460)
       (Point 230 460)
       (Point 230 362)
       (Point 248 362)
      )
      (connect D0:1 D2:0
       (Point 463 352)
       (Point 510 352)
       (Point 510 415)
      )
     )
     (stackingOrder 0 1 2)
    )
    (active panel)
    (active panel)
   )
  )
  (component 26 "FORMULA"
   (name "Get the time")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr 1 "now() MOD (2^31)")
   )
   (views
    (icon
     (origin 51 148)
     (extent 118 25)
    )
    (detail
     (origin 81 169)
     (extent 178 62)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 27 "RANDOMNUMBERSEED"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Seed")
     (requires
      (datatype Int32)
      (shape "Scalar")
     )
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 65 198)
     (extent 110 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (configuration
   (connect D23:2 D0:1)
   (connect D23:3 D1:1)
   (connect D23:9 D2:1)
   (connect D23:8 D3:1)
   (connect D23:7 D4:1)
   (connect D23:4 D5:1)
   (connect D23:5 D6:1)
   (connect D23:6 D7:1)
   (connect D23:1 D8:1)
   (connect D27:0 D9:0)
   (connect D18:0 D9:1)
   (connect D14:1 D10:1)
   (connect D10:0 D11:0)
   (connect D11:1 D12:1)
   (connect D12:1 D13:0)
   (connect D8:1 D14:1)
   (connect D0:1 D14:2)
   (connect D1:1 D14:3)
   (connect D5:1 D14:4)
   (connect D6:1 D14:5)
   (connect D7:1 D14:6)
   (connect D4:1 D14:7)
   (connect D3:1 D14:8)
   (connect D2:1 D14:9)
   (connect D8:2 D15:1)
   (connect D0:2 D15:2)
   (connect D1:2 D15:3)
   (connect D5:2 D15:4)
   (connect D6:2 D15:5)
   (connect D7:2 D15:6)
   (connect D4:2 D15:7)
   (connect D3:2 D15:8)
   (connect D2:2 D15:9)
   (connect D15:1 D16:1)
   (connect D27:0 D18:0)
   (connect D18:1 D20:0)
   (connect D9:1 D21:0)
   (connect D20:1 D22:1)
   (connect D22:1 D23:1)
   (connect D24:1 D23:2)
   (connect D20:0 D24:0)
   (connect D17:0 D26:0)
   (connect D26:1 D27:1)
  )
 )
 (views
  (panel
   (origin 0 62)
   (extent 878 502)
   (widget 16 detail
    (title on)
    (origin 361 106)
    (extent 150 34)
   )
   (widget 10 detail
    (title on)
    (origin 361 179)
    (extent 150 34)
   )
   (widget 20 detail
    (title on)
    (origin 185 107)
    (extent 151 106)
    (format buttons)
   )
   (widget 11 icon
    (title off)
    (origin 23 177)
    (extent 138 37)
    (format button)
   )
   (widget 9 icon
    (title off)
    (origin 23 124)
    (extent 136 35)
   )
   (widget 17 icon
    (title off)
    (origin 22 74)
    (extent 139 35)
   )
   (widget 19 detail
    (title on)
    (origin 540 106)
    (extent 320 106)
    (editing disabled)
   )
  )
  (detail
   (origin 0 62)
   (extent 1004 664)
   (configuration
    (connect D23:2 D0:1
     (Point 472 395)
     (Point 480 395)
     (Point 480 375)
     (Point 490 375)
     (Point 490 345)
     (Point 542 345)
    )
    (connect D23:3 D1:1
     (Point 472 425)
     (Point 480 425)
     (Point 480 415)
     (Point 490 415)
     (Point 490 385)
     (Point 542 385)
    )
    (connect D23:9 D2:1
     (Point 472 605)
     (Point 490 605)
     (Point 490 625)
     (Point 542 625)
    )
    (connect D23:8 D3:1
     (Point 472 575)
     (Point 490 575)
     (Point 490 585)
     (Point 542 585)
    )
    (connect D23:7 D4:1
     (Point 472 545)
     (Point 542 545)
    )
    (connect D23:4 D5:1
     (Point 472 455)
     (Point 490 455)
     (Point 490 425)
     (Point 542 425)
    )
    (connect D23:5 D6:1
     (Point 472 485)
     (Point 490 485)
     (Point 490 465)
     (Point 542 465)
    )
    (connect D23:6 D7:1
     (Point 472 515)
     (Point 490 515)
     (Point 490 505)
     (Point 542 505)
    )
    (connect D23:1 D8:1
     (Point 472 365)
     (Point 480 365)
     (Point 480 335)
     (Point 490 335)
     (Point 490 305)
     (Point 542 305)
    )
    (connect D27:0 D9:0
     (Point 120 225)
     (Point 120 240)
     (Point 50 240)
     (Point 50 354)
    )
    (connect D18:0 D9:1
     (Point 120 329)
     (Point 120 335)
     (Point 10 335)
     (Point 10 375)
     (Point 18 375)
    )
    (connect D14:1 D10:1
     (Point 835 265)
     (Point 852 265)
    )
    (connect D10:0 D11:0
     (Point 930 284)
     (Point 930 299)
    )
    (connect D11:1 D12:1
     (Point 1001 315)
     (Point 1010 315)
     (Point 1010 345)
     (Point 870 345)
     (Point 870 375)
     (Point 888 375)
    )
    (connect D12:1 D13:0
     (Point 971 365)
     (Point 990 365)
     (Point 990 405)
     (Point 930 405)
     (Point 930 420)
    )
    (connect D8:1 D14:1
     (Point 657 295)
     (Point 670 295)
     (Point 670 225)
     (Point 784 225)
    )
    (connect D0:1 D14:2
     (Point 657 335)
     (Point 680 335)
     (Point 680 235)
     (Point 784 235)
    )
    (connect D1:1 D14:3
     (Point 657 375)
     (Point 690 375)
     (Point 690 245)
     (Point 784 245)
    )
    (connect D5:1 D14:4
     (Point 657 415)
     (Point 700 415)
     (Point 700 255)
     (Point 784 255)
    )
    (connect D6:1 D14:5
     (Point 657 455)
     (Point 710 455)
     (Point 710 265)
     (Point 784 265)
    )
    (connect D7:1 D14:6
     (Point 657 495)
     (Point 740 495)
     (Point 740 275)
     (Point 784 275)
    )
    (connect D4:1 D14:7
     (Point 657 535)
     (Point 760 535)
     (Point 760 285)
     (Point 784 285)
    )
    (connect D3:1 D14:8
     (Point 657 575)
     (Point 770 575)
     (Point 770 295)
     (Point 784 295)
    )
    (connect D2:1 D14:9
     (Point 657 615)
     (Point 670 615)
     (Point 670 625)
     (Point 650 625)
     (Point 650 685)
     (Point 850 685)
     (Point 850 625)
     (Point 840 625)
     (Point 840 605)
     (Point 850 605)
     (Point 850 345)
     (Point 750 345)
     (Point 750 305)
     (Point 784 305)
    )
    (connect D8:2 D15:1
     (Point 657 315)
     (Point 670 315)
     (Point 670 305)
     (Point 650 305)
     (Point 650 215)
     (Point 770 215)
     (Point 770 195)
     (Point 840 195)
     (Point 840 255)
     (Point 830 255)
     (Point 830 275)
     (Point 840 275)
     (Point 840 335)
     (Point 780 335)
     (Point 780 575)
     (Point 794 575)
    )
    (connect D0:2 D15:2
     (Point 657 355)
     (Point 750 355)
     (Point 750 585)
     (Point 794 585)
    )
    (connect D1:2 D15:3
     (Point 657 395)
     (Point 730 395)
     (Point 730 595)
     (Point 794 595)
    )
    (connect D5:2 D15:4
     (Point 657 435)
     (Point 720 435)
     (Point 720 605)
     (Point 794 605)
    )
    (connect D6:2 D15:5
     (Point 657 475)
     (Point 710 475)
     (Point 710 615)
     (Point 794 615)
    )
    (connect D7:2 D15:6
     (Point 657 515)
     (Point 700 515)
     (Point 700 625)
     (Point 794 625)
    )
    (connect D4:2 D15:7
     (Point 657 555)
     (Point 690 555)
     (Point 690 635)
     (Point 794 635)
    )
    (connect D3:2 D15:8
     (Point 657 595)
     (Point 680 595)
     (Point 680 645)
     (Point 794 645)
    )
    (connect D2:2 D15:9
     (Point 657 635)
     (Point 670 635)
     (Point 670 655)
     (Point 794 655)
    )
    (connect D15:1 D16:1
     (Point 845 615)
     (Point 862 615)
    )
    (connect D27:0 D18:0
     (Point 120 225)
     (Point 120 260)
    )
    (connect D18:1 D20:0
     (Point 177 295)
     (Point 190 295)
     (Point 190 345)
     (Point 110 345)
     (Point 110 504)
    )
    (connect D9:1 D21:0
     (Point 81 375)
     (Point 100 375)
     (Point 100 405)
     (Point 50 405)
     (Point 50 420)
    )
    (connect D20:1 D22:1
     (Point 203 575)
     (Point 210 575)
     (Point 210 555)
     (Point 220 555)
     (Point 220 485)
     (Point 120 485)
     (Point 120 405)
     (Point 132 405)
    )
    (connect D22:1 D23:1
     (Point 247 405)
     (Point 267 405)
    )
    (connect D24:1 D23:2
     (Point 176 645)
     (Point 220 645)
     (Point 220 565)
     (Point 267 565)
    )
    (connect D20:0 D24:0
     (Point 110 618)
     (Point 110 630)
    )
    (connect D17:0 D26:0
     (Point 110 121)
     (Point 110 145)
    )
    (connect D26:1 D27:1
     (Point 171 160)
     (Point 190 160)
     (Point 190 190)
     (Point 50 190)
     (Point 50 210)
     (Point 62 210)
    )
   )
   (stackingOrder 0 1 2 3 4 5 6 7 8 9
     10 11 12 13 14 15 16 18 20 21
     22 23 24 25 19 27 26 17)
  )
  (active panel)
  (active panel)
  (numberFormats
   (realFormat standard)
   (realSigDigits 4)
   (realRadixSpec 4)
   (integerBase decimal)
  )
  (waveformSettings
   (timeSpan 0.02)
   (numPoints 256)
  )
 )
)
